#
# spec file for package xcalc
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xcalc
Version:        1.1.2
Release:        1.3
Summary:        Scientific calculator for X
License:        MIT
Group:          System/X11/Utilities
URL:            https://xorg.freedesktop.org/
Source0:        https://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
Source1:        https://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz.sig
Source2:        xcalc.keyring
Source3:        xcalc.desktop
Source4:        xcalc.png
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xt)
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6

%description
xcalc is a scientific calculator X11 client that can emulate a TI-30
or an HP-10C.

%prep
%setup -q
cp %{SOURCE3} .

%build
%configure
%make_build

%install
%make_install
%suse_update_desktop_file -i -u xcalc Utility Calculator
install -m0644 -D %{SOURCE4} %{buildroot}%{_datadir}/pixmaps/xcalc.png

%files
%license COPYING
%doc ChangeLog README.md
%{_bindir}/xcalc
%{_datadir}/applications/xcalc.desktop
%{_datadir}/pixmaps/xcalc.png
%dir %{_datadir}/X11/app-defaults
%{_datadir}/X11/app-defaults/XCalc
%{_datadir}/X11/app-defaults/XCalc-color
%{_mandir}/man1/xcalc.1%{?ext_man}

%changelog
* Fri May  5 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.1.2
  * gitlab CI: stop requiring Signed-off-by in commits
  * Add -version option
  * Fix -version handling to not require opening a display first
  * Stop casting function returns to void
  * Add -help option
  * Accept number keys on main keyboard when NumLock is on
  * Key color highlighting still incorrect
* Thu Aug 11 2022 Dirk Müller <dmueller@suse.com>
- modernize spec-file, move license to %%%%licensedir
- use gpg for source validation
* Sun Apr  3 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.1.1
  * This release fixes a regression introduced in xcalc 1.1.0 which
    caused the wrong set of buttons to be colored for the digit
    keys in TI mode.
* Tue Jun 11 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.1.0
  * This release adds base conversion (decimal, octal, hexadecimal),
    bitwise ops (and, or, xor, not, shift left/right, truncate), and
    a modulo operator to the default TI (infix, i.e. not RPN/postfix)
    calculator mode.  It also binds the Return key to the "=" button.
* Mon Feb 18 2019 sndirsch@suse.com
- Update to version 1.0.7
  * This release fixes things that cause warnings from gcc or
    cppcheck, as well as assorted build system maintenance and
    tuneups.
* Sat Jan 31 2015 sfalken@opensuse.org
- Update to version 1.0.6:
  + Replace index() call with strchr()
  + autogen.sh: Honor NOCONFIGURE=1
  + configure: Drop AM_MAINTAINER_MODE
  + Replace signal_t with void
  + Assume signal handlers return void, as C89 requires
  + Mark functions noreturn as suggested by gcc -Wmissing-noreturn
  + Rename "e" arguments to "ev" to avoid shadowing e() function
  + Remove redundant redeclaration of 'factorial'
  + Replace sprintf and strcpy calls with snprint4 and strlcpy
  + Remove unused min & max macros from math.h
  + Use the new M_E symbol from math.h
  + Use the new M_PI symbol from math.h
  + Drop Cray support
- Dropped xcalc-1.0.5.tar.bz2
* Sat Jan 19 2013 zaitor@opensuse.org
- Update to version 1.0.5:
  + Use table markup rather than tab stops. Aids DocBook
    translation.
  + Strip trailing whitespace.
  + Add const to parse_double() args to fix gcc -Wwrite-strings
    warnings.
  + config:
  - Move man pages into their own directory.
  - Replace deprecated AC_HELP_STRING with AS_HELP_STRING.
  + man:
  - Replace hard coded man page section with substitution strings
  - Remove trailing spaces and tabs.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xcalc from xorg-x11. Initial version: 1.0.4.1.
